@@ -323,6 +323,7 @@ OIDN_NAMESPACE_BEGIN
   {
     Default  = OIDN_QUALITY_DEFAULT,  // default quality
 
+    Fast     = OIDN_QUALITY_FAST,     // high performance (for interactive/real-time preview rendering)
     Balanced = OIDN_QUALITY_BALANCED, // balanced quality/performance (for interactive/real-time rendering)
     High     = OIDN_QUALITY_HIGH,     // high quality (for final-frame rendering)
   };
@@ -518,7 +519,7 @@ OIDN_NAMESPACE_BEGIN
       oidnExecuteFilterAsync(handle);
     }
 
-  #if defined(SYCL_LANGUAGE_VERSION)
+  #if defined(OIDN_SYCL_HPP)
     // Executes the filter of a SYCL device using the specified dependent events asynchronously, and
     // optionally returns an event for completion.
     sycl::event executeAsync(const std::vector<sycl::event>& depEvents)
@@ -832,6 +833,38 @@ OIDN_NAMESPACE_BEGIN
     return static_cast<Error>(oidnGetDeviceError(nullptr, &outMessage));
   }
 
+  // Returns whether the CPU device is supported.
+  inline bool isCPUDeviceSupported()
+  {
+    return oidnIsCPUDeviceSupported();
+  }
+
+  // Returns whether the specified SYCL device is supported.
+#if defined(OIDN_SYCL_HPP)
+  inline bool isSYCLDeviceSupported(const sycl::device& device)
+  {
+    return oidnIsSYCLDeviceSupported(&device);
+  }
+#endif
+
+  // Returns whether the specified CUDA device is supported.
+  inline bool isCUDADeviceSupported(int deviceID)
+  {
+    return oidnIsCUDADeviceSupported(deviceID);
+  }
+
+  // Returns whether the specified HIP device is supported.
+  inline bool isHIPDeviceSupported(int deviceID)
+  {
+    return oidnIsHIPDeviceSupported(deviceID);
+  }
+
+  // Returns whether the specified Metal device is supported.
+  inline bool isMetalDeviceSupported(MTLDevice_id device)
+  {
+    return oidnIsMetalDeviceSupported(device);
+  }
+
   // Creates a device of the specified type.
   inline DeviceRef newDevice(DeviceType type = DeviceType::Default)
   {
@@ -862,7 +895,7 @@ OIDN_NAMESPACE_BEGIN
     return DeviceRef(oidnNewDeviceByPCIAddress(pciDomain, pciBus, pciDevice, pciFunction));
   }
 
-#if defined(SYCL_LANGUAGE_VERSION)
+#if defined(OIDN_SYCL_HPP)
   // Creates a device from the specified SYCL queue.
   inline DeviceRef newSYCLDevice(const sycl::queue& queue)
   {
@@ -878,16 +911,15 @@ OIDN_NAMESPACE_BEGIN
   }
 #endif
 
-  // Creates a device from the specified CUDA device ID (negative value maps to the current device)
-  // and stream.
+  // Creates a device from the specified CUDA device ID and stream (null stream corresponds to the
+  // default stream).
   inline DeviceRef newCUDADevice(int deviceID, cudaStream_t stream)
   {
     return DeviceRef(oidnNewCUDADevice(&deviceID, &stream, 1));
   }
 
-  // Creates a device from the specified pairs of CUDA device IDs (negative ID corresponds to the
-  // current device) and streams (null stream corresponds to the default stream).
-  // Currently only one device ID/stream is supported.
+  // Creates a device from the specified pairs of CUDA device IDs and streams (null stream
+  // corresponds to the default stream). Currently only one device ID/stream is supported.
   inline DeviceRef newCUDADevice(const std::vector<int>& deviceIDs,
                                  const std::vector<cudaStream_t>& streams)
   {
@@ -896,16 +928,15 @@ OIDN_NAMESPACE_BEGIN
                                        static_cast<int>(streams.size())));
   }
 
-  // Creates a device from the specified HIP device ID (negative ID corresponds to the current
-  // device) and stream (null stream corresponds to the default stream).
+  // Creates a device from the specified HIP device ID and stream (null stream corresponds to the
+  // default stream).
   inline DeviceRef newHIPDevice(int deviceID, hipStream_t stream)
   {
     return DeviceRef(oidnNewHIPDevice(&deviceID, &stream, 1));
   }
 
-  // Creates a device from the specified pairs of HIP device IDs (negative ID corresponds to the
-  // current device) and streams (null stream corresponds to the default stream).
-  // Currently only one device ID/stream is supported.
+  // Creates a device from the specified pairs of HIP device IDs and streams (null stream
+  // corresponds to the default stream). Currently only one device ID/stream is supported.
   inline DeviceRef newHIPDevice(const std::vector<int>& deviceIDs,
                                 const std::vector<hipStream_t>& streams)
   {
